@@ -42,7 +42,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_token() -> Result<(), Error> {
-        pretty_env_logger::try_init();
+        pretty_env_logger::try_init().ok();
         let user = User::default().with_domain(&crate::domains::domains().await?.any().domain);
 
         let create = accounts::create(&user).await.unwrap();
